@@ -1,7 +1,7 @@
 from eda_report.cli import process_cli_args
 from eda_report.document import ReportDocument
 
-__version__ = '1.1.3'
+__version__ = '1.3.0'
 
 
 def get_word_report(data, *, title='Exploratory Data Analysis Report',
@@ -9,21 +9,25 @@ def get_word_report(data, *, title='Exploratory Data Analysis Report',
                     output_filename='eda-report.docx'):
     """Analyses the input data, and generates a report in *.docx* format.
 
-    The is simply a wrapper around the
-    :class:`~eda_report.document.ReportDocument` object.
+    This is simply a wrapper around the
+    :class:`~eda_report.document.ReportDocument` object, and the arguments
+    supplied are passed to it.
 
     :param data: The data to analyse.
-    :type data: ``pandas.DataFrame``, ``pandas.Series``, an array-like or
-        sequence.
+    :type data: an array-like or sequence.
     :param title: The top level heading for the generated report, defaults to
         'Exploratory Data Analysis Report'.
     :type title: str, optional
     :param graph_color: The color to apply to the generated graphs, defaults
-        to 'orangered'. Any valid matplotlib color specifier will do.
+        to 'orangered'. See the *matplotlib* `list of named colors`_ for all
+        available options.
     :type graph_color: str, optional
-    :param output_filename: The name to give the generated report file,
-        defaults to 'basic-report.docx'.
+    :param output_filename: The name and path to use in saving the generated
+        report file, defaults to 'eda-report.docx' in the current directory.
     :type output_filename: str, optional
+
+    .. _`list of named colors`:
+        https://matplotlib.org/stable/gallery/color/named_colors.html
     """
     ReportDocument(data, title=title, graph_color=graph_color,
                    output_filename=output_filename)
@@ -33,7 +37,11 @@ def run_from_cli():
     """Creates an exploratory data analysis report in *.docx* format using input
     from the command line interface.
 
-    Arguments passed from the command line are parsed using the
+    This is the function executed when the package is run as a script (using
+    ``python -m eda_report``. It is also the entry point for the ``eda_cli``
+    console script (command).
+
+    Arguments passed from the command line are captured using the
     :func:`~eda_report.cli.process_cli_args` function, and then supplied to the
     :func:`~eda_report.get_word_report` function to generate the report.
     """
