@@ -1,15 +1,18 @@
-from eda_report.read_file import df_from_file
-from eda_report import get_word_report
-from tkinter import Tk, Button, Frame, Canvas, PhotoImage
-from tkinter.filedialog import askopenfilename, asksaveasfilename
-from tkinter.simpledialog import askstring
-from tkinter.colorchooser import askcolor
-from tkinter.messagebox import showinfo
 import pkgutil
+from tkinter import Button, Canvas, Frame, PhotoImage, Tk
+from tkinter.colorchooser import askcolor
+from tkinter.filedialog import askopenfilename, asksaveasfilename
+from tkinter.messagebox import showinfo
+from tkinter.simpledialog import askstring
 
+from eda_report import get_word_report
+from eda_report.read_file import df_from_file
 
+# Load background image and icon
 background_image = pkgutil.get_data(__name__, "images/background.png")
 icon = pkgutil.get_data(__name__, "images/icon.png")
+
+# Introductory text
 description = """
 A simple application to help speed up exploratory data analysis and reporting.
 
@@ -20,32 +23,51 @@ Select a file to analyse, and it will be automatically summarised. The result\
 
 
 def run_in_gui():
-    """Starts a graphical user interface to the application.
+    """Starts the *graphical user interface* to the application.
+
+    This provides the entry point for the ``eda_report`` console script
+    (command).
     """
     root = Tk()
     root.title('eda_report')
     root.geometry('600x400')
     root.resizable(0, 0)
     root.wm_iconphoto(True, PhotoImage(data=icon))
-    EDA_Gui(master=root)
+    EDAGUI(master=root)
     root.mainloop()
 
 
-class EDA_Gui(Frame):
-    """This is the blueprint for the graphical user interface to the
-    application.
+class EDAGUI(Frame):
+    """This is the blueprint for the `tkinter`_ - based *graphical user
+    interface* to the package/application.
+
+    The graphical window is a *tkinter* ``Frame``, with a *button* that
+    opens a *file-dialog* to navigate to and select a file to analyse.
+
+    Once a file is selected, a *text-input widget* and *color-picker tool* pop
+    up to help set the report's *title* and *graph color* respectively.
+    Finally, a file-dialog to set the desired location and name for the report
+    is shown.
+
+    The collected *input file-path*, *title*, *color* and *output file-path*
+    are then passed to the :func:`~eda_report.get_word_report` function to
+    create the exploratory data analysis report document. A message-box will
+    be shown when the report is ready, or when an exception occurs.
+
+    .. _`tkinter`: https://docs.python.org/3/library/tkinter.html
     """
 
     def __init__(self, master=None, **kw):
         super().__init__(master)
         self.master = master
         self.configure(height=400, width=600)
-        self.create_widgets()
+        self._create_widgets()
         self.pack()
 
-    def create_widgets(self):
-        """Creates the widgets for the graphical user interface: A canvas with
-        introductory text, a button to select a file, and a background image.
+    def _create_widgets(self):
+        """Creates the widgets for the graphical user interface: A *canvas*
+        with the a *background image*, *introductory text*, and a *button* to
+        select a file.
         """
         # Create the canvas
         self.canvas = Canvas(self, width=600, height=400)
@@ -64,29 +86,32 @@ class EDA_Gui(Frame):
         # Add a button
         self.button = Button(
             self, text='Select a file', default='active', bg='teal',
-            fg='white', width=30, command=self.create_report, relief='flat',
+            fg='white', command=self.create_report, relief='flat',
         )
-        self.canvas.create_window(170, 270, anchor='nw', window=self.button)
+        self.canvas.create_window(170, 270, anchor='nw', height=40, width=250,
+                                  window=self.button)
 
         self.canvas.pack()
 
     def create_report(self):
-        """Collect input from the graphical user interface, and use the
-        :func:`eda_report.get_word_report` function to generate a report.
+        """Collects input from the graphical user interface, and uses the
+        :func:`~eda_report.get_word_report` function to generate a report.
         """
-        self.get_data_from_file()
-        self.get_report_title()
-        self.get_graph_color()
-        self.get_save_as_name()
+        self._get_data_from_file()
 
-        # Generate the report using the provided arguments
-        get_word_report(self.data, title=self.report_title,
-                        graph_color=self.graph_color,
-                        output_filename=self.save_name)
-        # Pop up message to declare that the report is finished
-        showinfo(message=f'Done! Report saved as {self.save_name!r}.')
+        if hasattr(self, 'data'):
+            self._get_report_title()
+            self._get_graph_color()
+            self._get_save_as_name()
 
-    def get_data_from_file(self):
+            # Generate the report using the provided arguments
+            get_word_report(self.data, title=self.report_title,
+                            graph_color=self.graph_color,
+                            output_filename=self.save_name)
+            # Pop up message to declare that the report is finished
+            showinfo(message=f'Done! Report saved as {self.save_name!r}.')
+
+    def _get_data_from_file(self, retries=2):
         """Creates a file dialog to help navigate to and select a file to
         analyse.
         """
@@ -96,11 +121,14 @@ class EDA_Gui(Frame):
         )
         if not file_name:
             showinfo(message='Please select a file to continue')
-            file_name = self.get_data_from_file()
+            if retries > 0:
+                file_name = self._get_data_from_file(retries - 1)
+            else:
+                self.master.quit()
         else:
             self.data = df_from_file(file_name)
 
-    def get_report_title(self):
+    def _get_report_title(self):
         """Creates a simple dialog to capture text input for the desired
         report title.
         """
@@ -113,7 +141,7 @@ class EDA_Gui(Frame):
         self.report_title = report_title if report_title else \
             'Exploratory Data Analysis Report'
 
-    def get_graph_color(self):
+    def _get_graph_color(self):
         """Creates a graphical color picking tool to help set the desired
         color for the generated graphs.
         """
@@ -124,7 +152,7 @@ class EDA_Gui(Frame):
         )[-1]
         self.graph_color = color if color is not None else 'orangered'
 
-    def get_save_as_name(self):
+    def _get_save_as_name(self):
         """Create a file dialog to help select a destination folder and file
         name for the generated report.
         """
